@@ -2,11 +2,6 @@
 
 # Test pmlcreate with the standard example input file
 
-if [ "$1" = 's' ]; then
-  out='/dev/null'
-else
-  out='2'
-fi
 tstdir=`pwd`
 tmpdir="/tmp/pmltest-$$"
 tmpinp='tmp.txt'
@@ -14,7 +9,11 @@ mkdir -p $tmpdir
 cd $tmpdir
 $tstdir/../pmlcreate -e > $tmpinp
 $tstdir/../pmlcreate $tmpinp
-$tstdir/../pmlvalid *.xml 1>& $out
+if [ "$1" = 's' ]; then
+  $tstdir/../pmlvalid *.xml 1>/dev/null
+else
+  $tstdir/../pmlvalid *.xml 1>&2
+fi
 es=$?
 rm $tmpinp *.xml
 cd $tstdir
