@@ -2,14 +2,13 @@
 
 # Test pmldigital applied to images from a digital camera
 
-if [ "$1" = 's' ]; then
-  out='/dev/null'
-else
-  out='2'
-fi
 tmpxml='tmp.xml'
 ../pmldigital -f 200*.jpg > $tmpxml
-../pmlvalid $tmpxml 1>& $out
+if [ "$1" = 's' ]; then
+  ../pmlvalid $tmpxml 1>/dev/null
+else
+  ../pmlvalid $tmpxml 1>&2
+fi
 es=$?
 rm $tmpxml
 exit $es
