@@ -2,11 +2,6 @@
 
 # Test pmldigital date/time offset option
 
-if [ "$1" = 's' ]; then
-  out='/dev/null'
-else
-  out='2'
-fi
 tmpxml='tmp.xml'
 ../pmldigital -f 2004d05f001.jpg > $tmpxml
 date0=`grep date $tmpxml | sed -e 's/ *<[^>]*>//g'`
